jdk/src/share/classes/javax/imageio/spi/IIORegistry.java
changeset 15263 f401cac7510b
parent 5506 202f599c92aa
child 23010 6dadb192ad81
child 23313 f100f0d49e0b
--- a/jdk/src/share/classes/javax/imageio/spi/IIORegistry.java	Mon Jan 14 18:31:48 2013 -0800
+++ b/jdk/src/share/classes/javax/imageio/spi/IIORegistry.java	Tue Jan 15 14:26:59 2013 +0400
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2007, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -64,9 +64,9 @@
  * <code>ImageWriter</code>, <code>ImageTranscoder</code>,
  * <code>ImageInputStream</code>, and <code>ImageOutputStream</code>.
  *
  * <p> Service providers found on the system classpath (<i>e.g.</i>,
  * the <code>jre/lib/ext</code> directory in Sun's implementation of
  * JDK) are automatically loaded as soon as this class is
  * instantiated.
  *
  * <p> When the <code>registerApplicationClasspathSpis</code> method
@@ -226,8 +226,10 @@
 
     private void registerInstalledProviders() {
         /*
-          We need load installed providers from lib/ext
-          directory in the privileged mode in order to
+          We need to load installed providers from the
+          system classpath (typically the <code>lib/ext</code>
+          directory in in the Java installation directory)
+          in the privileged mode in order to
           be able read corresponding jar files even if
           file read capability is restricted (like the
           applet context case).
@@ -64,9 +64,9 @@
  * <code>ImageInputStream</code>, and <code>ImageOutputStream</code>.
  *
- * <p> Service providers found on the system classpath (<i>e.g.</i>,
- * the <code>jre/lib/ext</code> directory in Sun's implementation of
- * JDK) are automatically loaded as soon as this class is
+ * <p> Service providers found on the system classpath (typically
+ * the <code>lib/ext</code> directory in the Java
+ * installation directory) are automatically loaded as soon as this class is
  * instantiated.
  *